function [ disease_pop, pheno ] = create_disease_pop_mut_v0( normalpop, popsize, logpmax, logpmin)
% starts from a passed population of size popsize and mutates individual parameters in randomly chosen members until
% popsize members are created that have a disease phenotpe
%pheno is an array that will hold the actual phenotypes

nparams=length(normalpop(1,:));
disease_pop=zeros(popsize, nparams);
pheno=zeros(popsize, 1);

if(popsize<2)
    fprintf('\nerror in create_disease_pop_v0: popsize %E too small', popsize);
    exit;
end
    

insmodel=SBmodel('ins_aw_v5_nM.txt');

%global declaration is important here, because ins_pNames needs to be
% used in the evaluation function
global ins_pNames;
%the original parameters from my simplified version of the SSQ02 model and their names 
[ins_pNames, ins_pValuesOriginal] = SBparameters(insmodel);
%note that hyperspace functions need row vectors, and these are column
%vectors
ins_pNames=transpose(ins_pNames);
ins_pValuesOriginal=transpose(ins_pValuesOriginal);
logpValuesOriginal=log10(ins_pValuesOriginal);


 %to display the whole shebang of a parameter array
 %for ctr=1:17, JNK= [pNames(ctr), pmin(ctr), pmax(ctr)]; disp(JNK); end
 
%now compile the loaded model
%default option zero means source code will be compiled
SBPDmakeMEXmodel(insmodel,'mex_insmodel_tmp',0);
simoptions.reltol=1e-7;
simoptions.abstol=1e-7;
%the following will run the insulin model up to time 60 and with default parameters
simres=SBPDsimulate('mex_insmodel_tmp',60,mex_insmodel_dis,ins_pNames,ins_pValuesOriginal,simoptions);


%a function that will define an opper bound for the integrated GLUT4
%trajectory
GLUT4MEMdata = simres.statevalues(:, 20);
GLUT4MEMpoly=pchip(simres.time, GLUT4MEMdata);
%defining an anonymous function GLUT4mem_extrap(t) will show the 
%membrane bound glut4 concentration at time t
%the factors below indicate how much lower the GLUT4 poly must
%be to be considered diseased
GLUT4mem_extrap_above_disease = @(t) ppval(GLUT4MEMpoly,t)*0.29*1.48;
thresh_disease=quad(GLUT4mem_extrap_above_disease, 0, 60);


%cap the number of trials to 
maxtrials=1000*popsize;

popctr=1;
for i=1:maxtrials
        %fprintf('\ntrial %d', i);
        %pick a randomly chosen parameter vector from the population
        mutind=randi([1 popsize]);
        mutlogparam=normalpop(mutind, :);  
        %now mutate a randomly chosen parameter from this parameter vector
        mutindex=randi([1 nparams]);
        mutlogparam(mutindex)=logpmin(mutindex)+rand*(logpmax(mutindex)-logpmin(mutindex));      
        mut_glut_uptake=eval_ins_obj_disease_v0(mutlogparam);
        %fprintf('\nmutating indiv %d index %d yielding glutuptake %E', mutind, mutindex, mut_glut_uptake);
        
        if(mut_glut_uptake<thresh_disease)
            disease_pop(popctr, :)=mutlogparam;
            pheno(popctr)=mut_glut_uptake;
            popctr=popctr+1;
            %fprintf('\nSUCCESS');
        %this allows jumping out of the loop if popsize is not a multiple of
        %mut_per_param
            if(popctr==popsize+1)
                return;
            end       
        end       
end
if(popctr<popsize)
     fprintf('\ncreate_disease_pop_v0: could fill only %d of %d individuals after %d trials', popctr, popsize, i);
     exit(1);
end
end

 
 