function [ pop, pheno ] = create_pop_plos( popsize, init_log_para , logpmax, logpmin)
% starts from a viable parameter point and creates a population of viable
% points through sequential random mutation. The returned array pop has
% dimension popsize*(n_params), and each of its rows contains one 
% viable point, pheno(i) contains the phenotype of the i-th individual


%first evaluate the reference parameter point for the model to get the
%viability threshold
insmodel=SBmodel('ins_aw_v5_nM.txt');
global ins_pNames;
[ins_pNames, ins_pValuesOriginal] = SBparameters(insmodel);
ins_pNames=transpose(ins_pNames);
ins_pValuesOriginal=transpose(ins_pValuesOriginal);
eval_simoptions.reltol=1e-7;
eval_simoptions.abstol=1e-7;
ref_simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,ins_pValuesOriginal,eval_simoptions);
GLUT4MEMdata = ref_simres.statevalues(:, 20);
GLUT4MEMpoly=pchip(ref_simres.time, GLUT4MEMdata);
GLUT4mem_extrap = @(t) ppval(GLUT4MEMpoly,t);
GLUT4mem_extrap_minus_1sdev = @(t) ppval(GLUT4MEMpoly,t)*0.59;
% the integral of the normal concentration minus one standard deviation
% will serve as the threshold for normal behavior, a parameter set needs
% to be above that threshold to be considered viable
thresh_normal=quad(GLUT4mem_extrap_minus_1sdev, 0, 60);

init_glut4mut = - eval_ins_obj_normal_plos( init_log_para );
if(init_glut4mut < thresh_normal)
   fprintf('\nerror in create_pop_plos: passed inviable parameter point with glut4 integral: %E', init_glut4mut); 
end

nparams=length(init_log_para);
pop=zeros(popsize, nparams);
pheno=zeros(popsize, 1);
if(popsize<2)
    fprintf('\nerror in create_pop_plos: popsize %E too small', popsize);
    exit;
end
    
    
% this routine mutates the starting parameter set sequentially mut_per_param
% times and stores all intermediate viable mutation products, repeats this
% procedure until popsize mutants were generated
mut_per_param=10;
popctr=1;
while(popctr<=popsize)
    j=1;
    mutlogparam=init_log_para;  
    while (j<=mut_per_param)
	% create new parameter point
        tmpparam=mutlogparam;
        mutindex=randi([1 nparams]);
        mutlogparam(mutindex)=logpmin(mutindex)+rand*(logpmax(mutindex)-logpmin(mutindex));
        % also note that the evaluation routine returns the NEGATIVE value of the 
        %integrated glut4 concentration, so the minus sign below converts 
        %it again to a positive value
        glut4mut = - eval_ins_obj_normal_plos( mutlogparam );
        while(glut4mut<thresh_normal)
                mutlogparam=tmpparam;
                mutindex=randi([1 nparams]);
                mutlogparam(mutindex)=logpmin(mutindex)+rand*(logpmax(mutindex)-logpmin(mutindex));
                glut4mut = - eval_ins_obj_normal_plos( mutlogparam );    
         end
     pop(popctr, :)=mutlogparam;
     pheno(popctr)=glut4mut;
     j=j+1;
     popctr=popctr+1;
     %this allows jumping out of the loop if popsize is not a multiple of
     %mut_per_param
     if(popctr==popsize+1)
         return;
     end
   end  
end


end
