

%the number of parameter sets to be tried 
ntrials=1.5e6;

 
run('/opt/SBTOOLBOX2/installSB.m');
addpath(genpath('/opt/SBTOOLBOX2'));
run('/opt/SBPD/installSBPD.m');
addpath(genpath('/opt/SBPD'));
RandStream.setGlobalStream(RandStream('mt19937ar','seed', 8052014));
 

%load insulin model
insmodel=SBmodel('ins_aw_v5_nM_plos.txt');

% global declaration is important here, because ins_pNames needs to be
% used in the evaluation function
global ins_pNames;

[ins_pNames, ins_pValuesOriginal] = SBparameters(insmodel);

ins_pNames=transpose(ins_pNames);
ins_pValuesOriginal=transpose(ins_pValuesOriginal);
logpValuesOriginal=log10(ins_pValuesOriginal);


pmin(1:length(ins_pValuesOriginal))=1e-3;
pmax(1:length(ins_pValuesOriginal))=1e3;

logpmin=log10(pmin);
logpmax=log10(pmax);
 
%now compile the loaded model
%default option zero means source code will be compiled
SBPDmakeMEXmodel(insmodel,'mex_insmodel',0);
simoptions.reltol=1e-7;
simoptions.abstol=1e-7;
%the following will run the insulin model up to time 60 and with default parameters
simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,ins_pValuesOriginal,simoptions);

 
%a block that computes the normal GLUT4 trajectory
GLUT4MEMdata = simres.statevalues(:, 20);
global GLUT4MEMpoly; 
GLUT4MEMpoly=pchip(simres.time, GLUT4MEMdata);
global GLUT4mem_extrap;
GLUT4mem_extrap = @(t) ppval(GLUT4MEMpoly,t);
%the numerical factors below indicate how much lower the GLUT4 poly must
%be to be considered diseased
GLUT4mem_extrap_above_disease = @(t) ppval(GLUT4MEMpoly,t)*0.29*1.48;
thresh_disease=quad(GLUT4mem_extrap_above_disease, 0, 60)


OUTFILE=strcat('ins_sampling_bruteforce_disease_plos_', date,'.mat');
viable_params_disease=[];
for i=1:ntrials
    	if (rem(i,1000) == 0)
        
        	nviables=numel(viable_params_disease)/15;
		%to monitor output
        	fprintf('\nparameters tried %d viable %d ratio %E', i, nviables, nviables/i);
    	save(OUTFILE);
    	end  
    
   	%generate a random parameter set on (-3,3)
	logranparams=-3+6.*rand(1,15);
	ranparams=10.^logranparams;

	eval_simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,ranparams,simoptions);

	% now integrate the glut4mem concentration over time and return that
    	% integral
	GLUT4MEMdata_eval = eval_simres.statevalues(:, 20);
	GLUT4MEMpoly_eval=pchip(eval_simres.time, GLUT4MEMdata_eval);
	GLUT4mem_extrap_eval = @(t) ppval(GLUT4MEMpoly_eval,t);
	
	gluc_uptake_ran=quad(GLUT4mem_extrap_eval, 0, 60);
	%if glucose uptake is greater than the disease threshold, then reject the
	%parameter set, i.e.,continue to the next one.
	if(gluc_uptake_ran>thresh_disease)
      		continue;
	end
	%the following will only be seen if the parameter set meets the above criterion 
	viable_params_disease=vertcat(viable_params_disease, ranparams);

end

