% a routine to sample the viable parameter space of the insulin pathway model

%the number of parameter sets to be tried 
ntrials=1.5e6;

addpath(genpath('/opt/HYPERSPACE/Files'))
run('/opt/SBTOOLBOX2/installSB.m');
addpath(genpath('/opt/SBTOOLBOX2'));
run('/opt/SBPD/installSBPD.m');
addpath(genpath('/opt/SBPD'));

RandStream.setGlobalStream(RandStream('mt19937ar','seed', 8052014));

insmodel=SBmodel('ins_aw_v5_nM_plos.txt');

% global declaration is important here, because ins_pNames needs to be
% used in the evaluation function
global ins_pNames;

[ins_pNames, ins_pValuesOriginal] = SBparameters(insmodel);
ins_pNames=transpose(ins_pNames);
ins_pValuesOriginal=transpose(ins_pValuesOriginal);
logpValuesOriginal=log10(ins_pValuesOriginal);

%The following sets the minmal and maximal boundaries for the 
%parameters, the order is as given in model ins_aw_v5_nM.txt
%and thus in the array pNames 
pmin(1:length(ins_pValuesOriginal))=1e-3;
pmax(1:length(ins_pValuesOriginal))=1e3;


logpmin=log10(pmin);
logpmax=log10(pmax);

%now compile the loaded model
%default option zero means source code will be compiled
SBPDmakeMEXmodel(insmodel,'mex_insmodel',0);
simoptions.reltol=1e-7;
simoptions.abstol=1e-7;
%the following will run the insulin model up to time 60 and with default parameters
simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,ins_pValuesOriginal,simoptions);



%a block that computes the normal GLUT4 trajedctory
GLUT4MEMdata = simres.statevalues(:, 20);
%'global' is needed for the function to be visible inside the evaluation
%function of the phenotype
global GLUT4MEMpoly; 
GLUT4MEMpoly=pchip(simres.time, GLUT4MEMdata);
global GLUT4mem_extrap;
GLUT4mem_extrap = @(t) ppval(GLUT4MEMpoly,t);
GLUT4mem_extrap_minus_1sdev = @(t) ppval(GLUT4MEMpoly,t)*0.59;
thresh_normal=quad(GLUT4mem_extrap_minus_1sdev, 0, 60)

OUTFILE=strcat('ins_sampling_bruteforce_normal_plos_', date,'.mat');
viable_params=[];
for i=1:ntrials
    	if (rem(i,1000) == 0)
        	nviables=numel(viable_params)/15;
		% to monitor output
        	fprintf('\nparameters tried %d viable %d ratio %E', i, nviables, nviables/i);
    		save(OUTFILE);
   	 end  
    
   	 %generate a random parameter set 
    	logranparams=-3+6.*rand(1,15);
    	ranparams=10.^logranparams;

    	eval_simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,ranparams,simoptions);

    	% now integrate the glut4mem concentration over time and return that
    	% integral
    	GLUT4MEMdata_eval = eval_simres.statevalues(:, 20);

    	%we require that at the last time point the glut4mem concentration has
    	%fallen below the half-maximal value
    	maxglut=max(GLUT4MEMdata_eval);
    	lastglut=GLUT4MEMdata_eval(end);
    	if(lastglut>=(maxglut/2))
            continue;
    	end


	%computinmg the actual glucose uptake with the random parameter set
	GLUT4MEMpoly_eval=pchip(eval_simres.time, GLUT4MEMdata_eval);
	GLUT4mem_extrap_eval = @(t) ppval(GLUT4MEMpoly_eval,t);
	% the integral of 
	gluc_uptake_ran=quad(GLUT4mem_extrap_eval, 0, 60);
	%reject this parameter set if glucose uptake is below the threshold
	if(gluc_uptake_ran<thresh_normal)
      		continue;
	end
	% add the new parameter set to the sample
	%the following will only be seen if the parameter set meets the criteria
	viable_params=vertcat(viable_params, ranparams);

end

