%loads a sample of viable parameter vectors from different regions in parameter
%space, expands each vector into a population of related viable vectors and 
%computes regression statistics, 

%number of populations to generate
samplesize=100;
%size of each population
popsize=1000;

%the file reads the output files of the routine ins_sampling_bruteforce*.m
load('[enter your input file name here]');
lendatnorm=length(outputVolint_normal.V(:,1));

RandStream.setGlobalStream(RandStream('mt19937ar','seed', 25032014));

%now generate a random subset of data of length samplesize
sampledat_norm=outputVolint_normal.V(randperm(lendatnorm, samplesize), :);

pmin(1:length(ins_pValuesOriginal))=1e-3;
pmax(1:length(ins_pValuesOriginal))=1e3;
logpmin=log10(pmin);
logpmax=log10(pmax);

%various arrays that will hold regression statistics
pop_anal_plogit_regrcoeff=[];
pop_anal_plogit=[];
pop_anal_adjR2_linregr=[];
pop_anal_adjR2_linregr_int=[];
pop_anal_adjR2_linregr_regrcoeff=[];
pop_anal_adjR2_linregr_pval=[];

OUTFILE_POP=strcat('pop_anal_plos_', date,'.mat');
fprintf('\nsaving data to %s', OUTFILE_POP);

for i=1:samplesize
    %to monitor output
    fprintf('\n now analyzing population %d', i);
    normpop=[];
    normpheno=[];
    [normpop, normpheno]  = create_pop_plos( popsize, sampledat_norm(i, :) , logpmax, logpmin);
    %now create a mutant population where everybody has the disease
    %phenotype
    dispop=[];
    dispheno=[];
    [dispop, dispheno] = create_disease_pop_mut_v0( normpop, popsize, logpmax, logpmin); 
    % define data arrays for both diseased and normal state, note that disease
    % state comes first
    % for the purpose of logistic regression, the diseased state will be
    % assigned a one and the normal state a zero
    sampledat=vertcat(dispop, normpop);
    pheno_binary=zeros(2*popsize,1);
    pheno_binary(popsize+1:2*popsize)=1;
    pheno_continuous=vertcat(dispheno, normpheno);
 
    %logistic regression, for the 2011 version of matlab
    [Blogit,DEVlogit,STATSlogit]=glmfit(sampledat, pheno_binary,'binomial', 'link', 'logit');

    %for regular regression analysis, for 2011 version of matlab
    linreg_stats=regstats(pheno_continuous,sampledat, 'linear');
    %the same with some interaction terms
    intreg_stats=regstats(pheno_continuous,sampledat, 'interaction');

    pop_anal_plogit_regrcoeff=[pop_anal_plogit_regrcoeff STATSlogit.beta];
    pop_anal_plogit=[pop_anal_plogit STATSlogit.p];
    
    pop_anal_adjR2_linregr=[pop_anal_adjR2_linregr linreg_stats.adjrsquare];
    pop_anal_adjR2_linregr_int=[pop_anal_adjR2_linregr_int intreg_stats.adjrsquare];
    
    pop_anal_adjR2_linregr_regrcoeff=[pop_anal_adjR2_linregr_regrcoeff linreg_stats.tstat.beta];
    pop_anal_adjR2_linregr_pval=[pop_anal_adjR2_linregr_pval linreg_stats.tstat.pval];
    save(OUTFILE_POP);
end

%transpose result matrices
pop_anal_plogit_regrcoeff=transpose(pop_anal_plogit_regrcoeff);
pop_anal_plogit=transpose(pop_anal_plogit);

pop_anal_adjR2_linregr_regrcoeff=transpose(pop_anal_adjR2_linregr_regrcoeff);
pop_anal_adjR2_linregr_pval=transpose(pop_anal_adjR2_linregr_pval);
save(OUTFILE_POP);





 



