%loads a sample of viable parameter vectors from different regions in parameter
%space, expands each vector into a population of related viable vectors and
%simulates the population's evolution under random parameter change and stabilizing selection, 
%all the while collecting statistics, such as data on the sensitivity coefficients

%number of populations to generate
npop=1;
%population size
popsize=100;
%number of rounds of selection and mutation to simulate
maxgen=10000;
%number of generations after which data is collected, maxgen MUST be
%divisible by this number
sampling_interval=1;
if(rem(maxgen, sampling_interval) ~= 0)
    fprintf('\nerror in pop_drift_sim: invalid sampling interval');
end

%fractional change to use in computing sensitivity coefficient
frac_change=1.1;

RandStream.setGlobalStream(RandStream('mt19937ar','seed', 10072014));

%the program reads the output file generated by routines  
%ins_sampling_bruteforce*.m
load('[enter your input file name here]');
lendatnorm=length(outputVolint_normal.V(:,1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%first evaluate the reference parameter point for the model to get the
%viability threshold
insmodel=SBmodel('ins_aw_v5_nM.txt');
global ins_pNames;
[ins_pNames, ins_pValuesOriginal] = SBparameters(insmodel);
ins_pNames=transpose(ins_pNames);
ins_pValuesOriginal=transpose(ins_pValuesOriginal);
eval_simoptions.reltol=1e-7;
eval_simoptions.abstol=1e-7;
%to compute the normal insulin threshold
ref_simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,ins_pValuesOriginal,eval_simoptions);
GLUT4MEMdata = ref_simres.statevalues(:, 20);
GLUT4MEMpoly=pchip(ref_simres.time, GLUT4MEMdata);
GLUT4mem_extrap = @(t) ppval(GLUT4MEMpoly,t);
GLUT4mem_extrap_minus_1sdev = @(t) ppval(GLUT4MEMpoly,t)*0.59;
thresh_normal=quad(GLUT4mem_extrap_minus_1sdev, 0, 60);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%now generate a random subset of data of length npop
sampledat_norm=outputVolint_normal.V(randperm(lendatnorm, npop), :);
nparams=length(ins_pValuesOriginal);
pmin(1:nparams)=1e-3;
pmax(1:nparams)=1e3;
logpmin=log10(pmin);
logpmax=log10(pmax);
OUTFILE_POP=strcat('pop_drift_sim_plos_', date,'.mat');
fprintf('\nsaving data to %s', OUTFILE_POP);

popctr=1;
genctr=1;

%arrays to hold populations and phenotypes
pop=zeros(popsize, nparams);
pheno=zeros(popsize, 1);
initpop=zeros(popsize, nparams);
initpheno=zeros(popsize, 1);

nsamples=maxgen/sampling_interval+1;
sampletime=zeros(npop, nsamples);
sens_coeff=zeros(npop, nsamples, popsize, nparams);
mean_sens_coeff=zeros(npop, nsamples, nparams);
sdev_sens_coeff=zeros(npop, nsamples, nparams);
mean_dist_to_origin=zeros(npop, nsamples);
  
for popctr=1:npop
 
    samplectr=0;
    
    %to monitor output
    fprintf('\n now analyzing population %d', popctr);    
    [initpop, initpheno]  = pop_init_v0( popsize, sampledat_norm(popctr, :) , logpmax, logpmin, thresh_normal);
   
    pop=initpop;
    pheno=initpheno;
    %now loop over generations within a population
    for genctr=0:maxgen
        fprintf('\n genctr %d', genctr);
        
        %sample at the given sampling intervals
        %for each individual in the population,compute the sensitivity coefficient of each parameter
        if(rem(genctr, sampling_interval) == 0)
            samplectr=samplectr+1;
            sampletime(popctr, samplectr)=genctr;
            mdist=0;
                for indctr=1:popsize
                    sens_coeff(popctr, samplectr, indctr, :) = sensitivity_plos( frac_change, pop(indctr, :), logpmax, logpmin );
                    mdist=mdist + norm(pop(indctr, :)-logpmin);
                end
            mean_dist_to_origin(popctr, samplectr) = mdist/popsize; 
            
            %loop over all parameters and for each one of them calculate the mean
            %and standard deviation of sensitivity coefficients across the
            %whole population
            paractr=1;
            for paractr=1:nparams
                mean_sens_coeff(popctr, samplectr, paractr) = mean(sens_coeff(popctr, samplectr, :, paractr));  
                sdev_sens_coeff(popctr, samplectr, paractr) = std(sens_coeff(popctr, samplectr, :, paractr));        
            end        
        end
        save(OUTFILE_POP);
        
        %now call the function to perform mutation and selection
        [pop, pheno]=pop_mutsel_plos(pop, pheno, logpmax, logpmin, thresh_normal); 
    end 
    
     
    save(OUTFILE_POP);
end

 

 



 



