function [ sens_coeff_arr ] = sensitivity_plos( frac_change, log_para_vector, logpmax, logpmin )
%changes each parameter one by one by some multiplicative fraction
%in a random direction, and computes how much the total glucose uptake changes

if(frac_change<1 && frac_change > 2)
    fprintf('\npassed invalid value of para frac_change: %E to sensitivity', frac-change);
    exit;
end

%global declaration is important because this array will be needed in here
global ins_pNames
nparas=length(log_para_vector);

%will hold the sensitivity coefficients
sens_coeff_arr=zeros(1,nparas);

para_vector=10.^log_para_vector;
pmax=10.^logpmax;
pmin=10.^logpmin;

%first simulate the mex insulin model with the passed parameter vector
eval_simoptions.reltol=1e-7;
eval_simoptions.abstol=1e-7;
eval_simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,para_vector,eval_simoptions);
% now integrate the glut4mem concentration over time and return that
% integral
GLUT4MEMdata_eval = eval_simres.statevalues(:, 20);
GLUT4MEMpoly_eval=pchip(eval_simres.time, GLUT4MEMdata_eval);
GLUT4mem_extrap_eval = @(t) ppval(GLUT4MEMpoly_eval,t);
wt_output=quad(GLUT4mem_extrap_eval, 0, 60);

%a block to compute the sensitivity coefficient
for i=1:length(log_para_vector)
    pert_para_vector=para_vector;
    % default perturbation is multiplication unless the parameter becomes
    % too large or too small
    if(pert_para_vector(i)*frac_change>pmax(i))
        pert_para_vector(i)=pert_para_vector(i)/frac_change;
    else 
        pert_para_vector(i)=pert_para_vector(i)*frac_change;     
    end
    pert_simres=SBPDsimulate('mex_insmodel',60,mex_insmodel,ins_pNames,pert_para_vector,eval_simoptions);
    

    GLUT4MEMdata_pert = pert_simres.statevalues(:, 20);
    GLUT4MEMpoly_pert=pchip(pert_simres.time, GLUT4MEMdata_pert);
    GLUT4mem_extrap_pert = @(t) ppval(GLUT4MEMpoly_pert,t);
    pert_output=quad(GLUT4mem_extrap_pert, 0, 60);
    
   
    sens_coeff_arr(i)=((pert_output-wt_output)/wt_output)/((pert_para_vector(i)-para_vector(i))/para_vector(i));

    
    
end

 
end

